@@ -92,12 +92,16 @@ class InventoryValidator(object):
         else:
             self.all_versions = self.validate_version_sequence(inventory['versions'])
             digests_used = self.validate_versions(inventory['versions'], self.all_versions, self.unnormalized_digests)
-        if 'head' in inventory:
-            self.head = 'THERE_ARE_NO_VERSIONS' if len(self.all_versions) == 0 else self.all_versions[-1]
+        if 'head' not in inventory:
+            self.error("E036d")
+        elif len(self.all_versions) > 0:
+            self.head = self.all_versions[-1]
             if inventory['head'] != self.head:
                 self.error("E040", got=inventory['head'], expected=self.head)
-        else:
-            self.error("E036d")
+        if len(self.all_versions) == 0:
+            # Abort tests is we don't have a valid version sequence, otherwise
+            # there will likely be spurious subsequent error reports
+            return
         if 'manifest' in inventory and 'versions' in inventory:
             self.check_digests_present_and_used(self.manifest_files, digests_used)
         if 'fixity' in inventory:
@@ -118,6 +122,8 @@ class InventoryValidator(object):
         if type(manifest) != dict:
             self.error('E041c')
         else:
+            content_paths = set()
+            content_directories = set()
             for digest in manifest:
                 m = re.match(self.digest_regex(), digest)
                 if not m:
@@ -134,8 +140,12 @@ class InventoryValidator(object):
                         manifest_digests.add(norm_digest)
                     for file in manifest[digest]:
                         manifest_files[file] = norm_digest
-                        if not self.is_valid_content_path(file):
-                            self.error("E042", path=file)
+                        self.check_content_path(file, content_paths, content_directories)
+            # Check for conflicting content paths
+            for path in content_directories:
+                if path in content_paths:
+                    self.error("E101", path=path)
+
         return (manifest_files, unnormalized_digests)
 
     def validate_fixity(self, fixity, manifest_files):
@@ -195,7 +205,7 @@ class InventoryValidator(object):
             self.error("E044")
             return all_versions
         elif len(versions) == 0:
-            self.error("E008b")
+            self.error("E008")
             return all_versions
         # Validate version sequence
         # https://ocfl.io/draft/spec/#version-directories
@@ -215,7 +225,7 @@ class InventoryValidator(object):
                     max_version_num = (10 ** (n - 1)) - 1
                     break
             if not zero_padded:
-                self.error("E008a")
+                self.error("E009")
                 return all_versions
         if zero_padded:
             self.warn("W001")
@@ -226,14 +236,14 @@ class InventoryValidator(object):
                 all_versions.append(v)
             else:
                 if len(versions) != (n - 1):
-                    self.error("E009")  # Extra version dirs outside sequence
+                    self.error("E010")  # Extra version dirs outside sequence
                 return all_versions
         # We have now included all possible versions up to the zero padding
         # size, if there are more versions than this number then we must
         # have extra that violate the zero-padding rule or are out of
         # sequence
         if len(versions) > max_version_num:
-            self.error("E009")
+            self.error("E011")
         return all_versions
 
     def validate_versions(self, versions, all_versions, unnormalized_digests):
@@ -273,7 +283,7 @@ class InventoryValidator(object):
             if 'message' not in version:
                 self.warn('W007a', version=v)
             elif type(version['message']) != str:
-                self.error('E048b', version=v)
+                self.error('E094', version=v)
             if 'user' not in version:
                 self.warn('W007b', version=v)
             else:
@@ -312,8 +322,7 @@ class InventoryValidator(object):
                     self.error('E050e', version=version, digest=digest)
                 else:
                     for path in state[digest]:
-                        if not self.check_logical_path(path, logical_paths, logical_directories):
-                            self.error('E051', version=version, digest=digest, path=path)
+                        self.check_logical_path(path, version, logical_paths, logical_directories)
                     if digest not in unnormalized_digests:
                         # Exact string value must match, not just normalized
                         self.error("E050f", version=version, digest=digest)
@@ -325,25 +334,6 @@ class InventoryValidator(object):
                     self.error("E095", version=version, path=path)
         return digests
 
-    def check_logical_path(self, path, logical_paths, logical_directories):
-        """Check logical path and accumulate paths/directories for E095 check.
-
-        Neither a leading or trailing slash is allowed which is caught by the
-        split and then test for empty.
-
-        logical_paths and logical_directories are expected to sets.
-        """
-        valid = True
-        elements = path.split('/')
-        for element in elements:
-            if element in ['.', '..', '']:
-                valid = False
-                break
-        # Accumulate paths and directories
-        logical_paths.add(path)
-        logical_directories.add('/'.join(elements[0:-1]))
-        return valid
-
     def check_digests_present_and_used(self, manifest_files, digests_used):
         """Check all digests in manifest that are needed are present and used."""
         in_manifest = set(manifest_files.values())
@@ -365,15 +355,45 @@ class InventoryValidator(object):
         # Match anything
         return r'''^.*$'''
 
-    def is_valid_content_path(self, path):
-        """True if path is a valid content path."""
-        m = re.match(r'''^v\d+/''' + self.content_directory + r'''/(.*)''', path)
-        if not m:
-            return False
-        for element in m.group(1).split('/'):
-            if element in ('', '.', '..'):
-                return False
-        return True
+    def check_logical_path(self, path, version, logical_paths, logical_directories):
+        """Check logical path and accumulate paths/directories for E095 check.
+
+        logical_paths and logical_directories are expected to be sets.
+
+        Only adds good paths to the accumulated paths/directories.
+        """
+        if path.startswith('/') or path.endswith('/'):
+            self.error("E053", version=version, path=path)
+        else:
+            elements = path.split('/')
+            for element in elements:
+                if element in ['.', '..', '']:
+                    self.error("E052", version=version, path=path)
+                    return
+            # Accumulate paths and directories
+            logical_paths.add(path)
+            logical_directories.add('/'.join(elements[0:-1]))
+
+    def check_content_path(self, path, content_paths, content_directories):
+        """Check logical path and accumulate paths/directories for E101 check.
+
+        Only adds good paths to the accumulated paths/directories.
+        """
+        if path.startswith('/') or path.endswith('/'):
+            self.error("E100", path=path)
+        else:
+            m = re.match(r'''^(v\d+/''' + self.content_directory + r''')/(.*)''', path)
+            if m:
+                elements = m.group(2).split('/')
+                for element in elements:
+                    if element in ('', '.', '..'):
+                        self.error("E099", path=path)
+                        return
+                # Accumulate paths and directories
+                content_paths.add(path)
+                content_directories.add('/'.join([m.group(1)] + elements[0:-1]))
+            else:
+                self.error("E042", path=path)
 
     def validate_as_prior_version(self, prior):
         """Check that prior is a valid InventoryValidator for a prior version of the current inventory object.
